@@ -2,8 +2,8 @@
 # this module meant to provide crypto handling actions #
 ########################################################
 
-from Crypto.Cipher import AES
-from Crypto.Util.Padding import pad
+from Cryptodome.Cipher import AES
+from Cryptodome.Util.Padding import pad
 
 
 # will encrypt a data block
